@@ -255,6 +255,7 @@ __all__ = (
     "ImageStateType",
     "ImageTypeValuesType",
     "InstanceAttributeNameType",
+    "InstanceAutoRecoveryStateType",
     "InstanceEventWindowStateType",
     "InstanceExistsWaiterName",
     "InstanceGenerationType",
@@ -294,6 +295,7 @@ __all__ = (
     "Ipv6SupportValueType",
     "KeyPairExistsWaiterName",
     "KeyTypeType",
+    "LaunchTemplateAutoRecoveryStateType",
     "LaunchTemplateErrorCodeType",
     "LaunchTemplateHttpTokensStateType",
     "LaunchTemplateInstanceMetadataEndpointStateType",
@@ -852,6 +854,7 @@ InstanceAttributeNameType = Literal[
     "sriovNetSupport",
     "userData",
 ]
+InstanceAutoRecoveryStateType = Literal["default", "disabled"]
 InstanceEventWindowStateType = Literal["active", "creating", "deleted", "deleting"]
 InstanceExistsWaiterName = Literal["instance_exists"]
 InstanceGenerationType = Literal["current", "previous"]
@@ -1420,6 +1423,7 @@ IpamStateType = Literal[
 Ipv6SupportValueType = Literal["disable", "enable"]
 KeyPairExistsWaiterName = Literal["key_pair_exists"]
 KeyTypeType = Literal["ed25519", "rsa"]
+LaunchTemplateAutoRecoveryStateType = Literal["default", "disabled"]
 LaunchTemplateErrorCodeType = Literal[
     "launchTemplateIdDoesNotExist",
     "launchTemplateIdMalformed",
